@@ -2,4 +2,7 @@ def sumSimple(num1,num2):
     return num1 + num2
 
 def restSimple(num1,num2):
-    return num1 - num2    
\ No newline at end of file
+    return num1 - num2    
+
+def multSimple(num1,num2):
+    return num1 * num2    
\ No newline at end of file
